@@ -43,7 +43,6 @@
 #'
 #' @export
 bed_cluster <- function(x, max_dist = 0) {
-
   if (!is.tbl_interval(x)) x <- as.tbl_interval(x)
 
   res <- group_by(x, chrom, add = TRUE)
@@ -54,6 +53,9 @@ bed_cluster <- function(x, max_dist = 0) {
   res <- mutate(res, .id = .id_merge)
   res <- select(res, !! quo(-one_of(".id_merge", ".overlap_merge")))
   res <- ungroup(res)
-
+  res <- mutate(
+    res,
+    .id = match(.id, unique(.id))
+  )
   res
 }
