@@ -1,7 +1,7 @@
 context("astyle")
 
 test_that("source code formatting", {
-  skip('run `astyle` test manually')
+  skip("run `astyle` test manually")
   skip_on_cran()
   skip_on_os("windows")
   skip_on_travis()
@@ -9,4 +9,3 @@ test_that("source code formatting", {
 
   expect_warning(astyle("--dry-run"), NA)
 })
-
